==> helix-0.8.0-src.zip: helix-0.8.0/helix-core/src/main/java/org/apache/helix/manager/zk/HelixManagerStateListener.java <==
package org.apache.helix.manager.zk;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.helix.HelixManager;


public interface HelixManagerStateListener {

  /**
   * Placeholder method for ensure backward compatible.
   * User will need to implement this method when Helix support async connecting to zookeeper.
   *
   * Invoked when the HelixManager connection to zookeeper is established
   * @param helixManager HelixManager that is successfully connected
   */
  void onConnected(HelixManager helixManager) throws Exception;

  /**
   * Invoked when the HelixManager connection to zookeeper is disconnected
   *
   * @param helixManager HelixManager that fails to be connected
   * @param error connection error
   */
  void onDisconnected(HelixManager helixManager, Throwable error) throws Exception;
}

==> helix-0.9.10-src.zip: helix-0.9.10/helix-core/src/main/java/org/apache/helix/manager/zk/HelixManagerStateListener.java <==
package org.apache.helix.manager.zk;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.helix.HelixManager;


public interface HelixManagerStateListener {

  /**
   * Placeholder method for ensure backward compatible.
   * User will need to implement this method when Helix support async connecting to zookeeper.
   *
   * Invoked when the HelixManager connection to zookeeper is established
   * @param helixManager HelixManager that is successfully connected
   */
  void onConnected(HelixManager helixManager) throws Exception;

  /**
   * Invoked when the HelixManager connection to zookeeper is closed unexpectedly.
   *
   * @param helixManager HelixManager that fails to be connected
   * @param error connection error
   */
  void onDisconnected(HelixManager helixManager, Throwable error) throws Exception;
}
